"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
class DBTransaction {
    /**
     *
     * @param transaction
     */
    constructor(transaction) {
        this.rolledBack = false;
        this.transaction = transaction;
    }
    begin() {
        return __awaiter(this, void 0, void 0, function* () {
            yield this.doTransactionBegin();
            this.transaction.begin();
            this.transaction.addCommitListener(() => this.doTransactionCommit());
            this.transaction.addRollbackListener(() => this.doTransactionRollback());
            this.transaction.addEndListener(() => this.doTransactionEnd());
        });
    }
    query(sql, ...bindArrs) {
        return this.runQueryPrivate(sql, bindArrs);
    }
    queryAssoc(sql, bindObj) {
        return this.runQueryAssocPrivate(sql, bindObj);
    }
    doTransactionBegin() {
        return this.runQueryPrivate(this.getTransactionBeginSQL());
    }
    // tslint:disable-next-line:prefer-function-over-method
    getTransactionBeginSQL() {
        return 'BEGIN';
    }
    doTransactionCommit() {
        return this.runQueryPrivate(this.getTransactionCommitSQL());
    }
    // tslint:disable-next-line:prefer-function-over-method
    getTransactionCommitSQL() {
        return 'COMMIT';
    }
    doTransactionRollback() {
        this.rolledBack = true;
        return this.runQueryPrivate(this.getTransactionRollbackSQL());
    }
    // tslint:disable-next-line:prefer-function-over-method
    getTransactionRollbackSQL() {
        return 'ROLLBACK';
    }
    end() {
        this.transaction.end();
    }
    isRolledBack() {
        return this.rolledBack;
    }
}
exports.DBTransaction = DBTransaction;
//# sourceMappingURL=DBTransaction.js.map